@@ -30,12 +30,12 @@ get '/ajax/content/report/halfduplex' => require_login sub {
 
     if ( request->is_ajax ) {
         my $json = to_json( \@results );
-        template 'ajax/report/halfduplex.tt', { results => $json }, { layout => undef };
+        template 'ajax/report/halfduplex.tt', { results => $json }, { layout => 'noop' };
     }
     else {
         header( 'Content-Type' => 'text/comma-separated-values' );
         template 'ajax/report/halfduplex_csv.tt',
-            { results => \@results }, { layout => undef };
+            { results => \@results }, { layout => 'noop' };
     }
 };
 
